@@ -138,7 +138,7 @@ def get_return_annotation(func: Callable) -> Optional[type]:
         or hasattr(ret_annotation, "__origin__")
     ):
         raise CouldNotResolve(
-            f"Unable to follow return annotation of {fully_qualified_name(func)}."
+            f"Unable to follow return annotation of {get_name_for_debugging(func)}."
         )
 
     return ret_annotation
@@ -149,6 +149,14 @@ def fully_qualified_name(thing: Union[type, Callable]) -> str:
     return thing.__module__ + "." + thing.__qualname__
 
 
+def get_name_for_debugging(thing: Union[type, Callable]) -> str:
+    """Construct the fully qualified name or some readable information of a type."""
+    try:
+        return fully_qualified_name(thing)
+    except (AttributeError, TypeError):
+        return repr(thing)
+
+
 @lru_cache(maxsize=None)
 def closest_module(components: Tuple[str, ...]) -> Tuple[Any, int]:
     """Find closest importable module."""
